/* Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by 
 *  Björnsen Beratende Ingenieure GmbH 
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.artifacts.sinfo.util;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import net.sf.jasperreports.engine.JRDataSource;
import net.sf.jasperreports.engine.JRException;
import net.sf.jasperreports.engine.JRField;

/**
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public final class MetaAndTableJRDataSource implements JRDataSource
{
    private List<String[]> data = new ArrayList<>();

    private Map<String, String> metaData = new HashMap<>();

    private int index = -1;

    public void addData(final String[] data) {
        this.data.add(data);
    }

    public void addMetaData(final String key, final String value) {
        this.metaData.put(key, value);
    }

    @Override
	public boolean next() throws JRException
    {
        index++;

        return index < data.size();
    }

    @Override
	public Object getFieldValue(final JRField field) throws JRException
    {
        final String fieldName = field.getName();
        
        if( fieldName.startsWith("meta:"))
        	return metaData.get(fieldName.substring("meta:".length()));

        if( fieldName.startsWith("data:"))
        {
        	int column = Integer.valueOf(fieldName.substring("data:".length()));
        	return data.get(index)[column];
        }
        
        return null;
    }
}